changeset 17839:b4a81f70d905

Coding system names changed as follows: internal -> emacs-mule, automatic-conversion -> undecided. Coding category name changes as follows: coding-category-internal -> coding-category-emacs-mule.
author Kenichi Handa <handa@m17n.org>
date Fri, 16 May 1997 00:59:00 +0000
parents b726d209302c
children 2517414676ed
files lisp/gnus/gnus-mule.el lisp/international/mule-conf.el lisp/mail/rmail.el
diffstat 3 files changed, 21 insertions(+), 21 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/gnus/gnus-mule.el	Fri May 16 00:58:58 1997 +0000
+++ b/lisp/gnus/gnus-mule.el	Fri May 16 00:59:00 1997 +0000
@@ -208,7 +208,7 @@
   (add-hook 'message-send-mail-hook
 	    'gnus-mule-message-send-mail-function))
 
-(gnus-mule-add-group "" 'automatic-conversion)
+(gnus-mule-add-group "" 'undecided)
 (gnus-mule-add-group "fj" 'iso-2022-7)
 (gnus-mule-add-group "alt.chinese.text" 'hz-gb-2312)
 (gnus-mule-add-group "alt.hk" 'hz-gb-2312)
--- a/lisp/mail/rmail.el	Fri May 16 00:58:58 1997 +0000
+++ b/lisp/mail/rmail.el	Fri May 16 00:59:00 1997 +0000
@@ -1403,7 +1403,7 @@
 		     (replace-match "\n^_")))); 2 chars: "^" and "_"
 	       (or rmail-enable-mime
 		   (not rmail-enable-decoding-message)
-		   (decode-coding-region start (point) 'automatic-conversion))
+		   (decode-coding-region start (point) 'undecided))
 	       (narrow-to-region (point) (point-max))
 	       (setq count (1+ count)))
 	      ;;*** Mail format
@@ -1466,7 +1466,7 @@
 	       (insert ?\^_)
 	       (or rmail-enable-mime
 		   (not rmail-enable-decoding-message)
-		   (decode-coding-region start (point) 'automatic-conversion))
+		   (decode-coding-region start (point) 'undecided))
 	       (narrow-to-region (point) (point-max)))
 	      ;;
 	      ;; This kludge is because some versions of sendmail.el
--- a/lisp/international/mule-conf.el	Fri May 16 00:58:58 1997 +0000
+++ b/lisp/international/mule-conf.el	Fri May 16 00:59:00 1997 +0000
@@ -214,23 +214,23 @@
      (vector nil ?= "Do no conversion" nil nil))
 (put 'no-conversion 'eol-type 0)
 
-(put 'automatic-conversion-unix 'coding-system 'automatic-conversion)
-(put 'automatic-conversion-unix 'eol-type 0)
-(put 'automatic-conversion-dos 'coding-system 'automatic-conversion)
-(put 'automatic-conversion-dos 'eol-type 1)
-(put 'automatic-conversion-mac 'coding-system 'automatic-conversion)
-(put 'automatic-conversion-mac 'eol-type 2)
-(put 'automatic-conversion 'coding-system
+(put 'undecided-unix 'coding-system 'undecided)
+(put 'undecided-unix 'eol-type 0)
+(put 'undecided-dos 'coding-system 'undecided)
+(put 'undecided-dos 'eol-type 1)
+(put 'undecided-mac 'coding-system 'undecided)
+(put 'undecided-mac 'eol-type 2)
+(put 'undecided 'coding-system
      (vector t ?+ "Detect coding-system automatically" nil nil))
-(put 'automatic-conversion 'eol-type
-     (vector 'automatic-conversion-unix
-	     'automatic-conversion-dos
-	     'automatic-conversion-mac))
+(put 'undecided 'eol-type
+     (vector 'undecided-unix
+	     'undecided-dos
+	     'undecided-mac))
 
 ;; Coding systems not specific to each language environment.
 
 (make-coding-system
- 'internal 0 ?=
+ 'emacs-mule 0 ?=
  "Internal coding system used in a buffer.")
 
 (make-coding-system
@@ -277,15 +277,15 @@
 ;; The other coding-systems are defined in each language specific
 ;; section of languages.el.
 
 ;; Setting coding system 'automatic-conversion for reading any files.
 ;; Though, compiled Emacs Lisp files (*.elc) should never be decoded
 ;; nor encoded.
 
 (setq coding-system-alist
       '((insert-file-contents
 	 ("\\.elc$" . (no-conversion . nil))
 	 ("loaddefs.el$" . (no-conversion . nil))
-	 ("" . (automatic-conversion . nil)))
+	 ("" . (undecided . nil)))
 	(write-region
 	 ("\\.elc$" . (nil . no-conversion))
 	 ("loaddefs.el$" . (nil . no-conversion)))))
@@ -298,7 +298,7 @@
 ;; values are set by the command `setup-language-environment' for each
 ;; language environment.
 
-(setq coding-category-internal	'internal
+(setq coding-category-emacs-mule 'emacs-mule
       coding-category-sjis	'sjis
       coding-category-iso-7	'iso-2022-7
       coding-category-iso-8-1	'iso-8859-1
@@ -315,6 +315,6 @@
    coding-category-sjis 
    coding-category-big5
    coding-category-binary
-   coding-category-internal))
+   coding-category-emacs-mule))
 
 ;;; mule-conf.el ends here
@@ -277,15 +277,15 @@
 ;; section of languages.el.
 
-;; Setting coding system 'automatic-conversion for reading any files.
-;; Though, compiled Emacs Lisp files (*.elc) should never be decoded
-;; nor encoded.
+;; Setting coding system 'undecided for reading any files.  Though,
+;; compiled Emacs Lisp files (*.elc) should never be decoded nor
+;; encoded.
 
 (setq coding-system-alist